@@ -1,4 +1,4 @@
-"""Test ETag feature"""
+"""Test EtagMixin"""
 
 import json
 import hashlib
@@ -17,6 +17,8 @@ from flask_smorest.exceptions import (
 )
 from flask_smorest.utils import get_appcontext
 
+from .utils import build_ref
+
 from .mocks import ItemNotFound
 
 
@@ -33,7 +35,6 @@ def app_with_etag(request, collection, schemas, app):
     blp = Blueprint("test", __name__, url_prefix="/test")
 
     if as_method_view:
-
         # Decorate each function
         @blp.route("/")
         class Resource(MethodView):
@@ -126,6 +127,8 @@ def app_with_etag(request, collection, schemas, app):
 
 
 class TestEtag:
+    """Test EtagMixin"""
+
     @pytest.mark.parametrize("extra_data", [None, {}, {"answer": 42}])
     def test_etag_generate_etag(self, extra_data):
         blp = Blueprint("test", __name__)
@@ -192,57 +195,56 @@ class TestEtag:
 
     @pytest.mark.parametrize("method", HTTP_METHODS)
     @pytest.mark.parametrize("etag_disabled", (True, False))
-    def test_etag_check_etag_wrong_method_warning(self, app, method, etag_disabled):
+    def test_etag_check_etag_wrong_method_warning(
+        self, app, method, etag_disabled, recwarn
+    ):
         app.config["ETAG_DISABLED"] = etag_disabled
         blp = Blueprint("test", __name__)
 
-        with pytest.warns(None) as record:
-            with app.test_request_context(
-                "/",
-                method=method,
-                headers={"If-Match": ""},
-            ):
-                # Ignore ETag check fail. Just testing the warning.
-                try:
-                    blp.check_etag(None)
-                except PreconditionFailed:
-                    pass
-                if method in ["PUT", "PATCH", "DELETE"]:
-                    assert not record
-                else:
-                    assert len(record) == 1
-                    assert record[0].category == UserWarning
-                    assert str(record[0].message) == (
-                        f"ETag cannot be checked on {method} request."
-                    )
+        with app.test_request_context(
+            "/",
+            method=method,
+            headers={"If-Match": ""},
+        ):
+            # Ignore ETag check fail. Just testing the warning.
+            try:
+                blp.check_etag(None)
+            except PreconditionFailed:
+                pass
+        if method in ["PUT", "PATCH", "DELETE"]:
+            assert not recwarn
+        else:
+            assert len(recwarn) == 1
+            assert recwarn[0].category == UserWarning
+            assert str(recwarn[0].message) == (
+                f"ETag cannot be checked on {method} request."
+            )
 
     @pytest.mark.parametrize("method", HTTP_METHODS)
-    def test_etag_verify_check_etag_warning(self, app, method):
+    def test_etag_verify_check_etag_warning(self, app, method, recwarn):
         blp = Blueprint("test", __name__)
         old_item = {"item_id": 1, "db_field": 0}
         old_etag = blp._generate_etag(old_item)
 
-        with pytest.warns(None) as record:
-            with app.test_request_context(
-                "/",
-                method=method,
-                headers={"If-Match": old_etag},
-            ):
-                blp._verify_check_etag()
-                if method in ["PUT", "PATCH", "DELETE"]:
-                    assert len(record) == 1
-                    assert record[0].category == UserWarning
-                    assert str(record[0].message) == (
-                        "ETag not checked in endpoint {} on {} request.".format(
-                            f_request.endpoint, method
-                        )
-                    )
-                else:
-                    assert not record
-                blp.check_etag(old_item)
-                record.clear()
-                blp._verify_check_etag()
-                assert not record
+        with app.test_request_context(
+            "/",
+            method=method,
+            headers={"If-Match": old_etag},
+        ):
+            blp._verify_check_etag()
+            if method in ["PUT", "PATCH", "DELETE"]:
+                assert len(recwarn) == 1
+                assert recwarn[0].category == UserWarning
+                assert str(recwarn[0].message) == (
+                    f"ETag not checked in endpoint {f_request.endpoint} "
+                    f"on {method} request."
+                )
+            else:
+                assert not recwarn
+            blp.check_etag(old_item)
+            recwarn.clear()
+            blp._verify_check_etag()
+            assert not recwarn
 
     @pytest.mark.parametrize("method", HTTP_METHODS_ALLOWING_SET_ETAG)
     @pytest.mark.parametrize("etag_disabled", (True, False))
@@ -305,21 +307,22 @@ class TestEtag:
 
     @pytest.mark.parametrize("etag_disabled", (True, False))
     @pytest.mark.parametrize("method", HTTP_METHODS)
-    def test_etag_set_etag_method_not_allowed_warning(self, app, method, etag_disabled):
+    def test_etag_set_etag_method_not_allowed_warning(
+        self, app, method, etag_disabled, recwarn
+    ):
         app.config["ETAG_DISABLED"] = etag_disabled
         blp = Blueprint("test", __name__)
 
-        with pytest.warns(None) as record:
-            with app.test_request_context("/", method=method):
-                blp.set_etag(None)
-            if method in HTTP_METHODS_ALLOWING_SET_ETAG:
-                assert not record
-            else:
-                assert len(record) == 1
-                assert record[0].category == UserWarning
-                assert str(record[0].message) == (
-                    f"ETag cannot be set on {method} request."
-                )
+        with app.test_request_context("/", method=method):
+            blp.set_etag(None)
+        if method in HTTP_METHODS_ALLOWING_SET_ETAG:
+            assert not recwarn
+        else:
+            assert len(recwarn) == 1
+            assert recwarn[0].category == UserWarning
+            assert str(recwarn[0].message) == (
+                f"ETag cannot be set on {method} request."
+            )
 
     @pytest.mark.parametrize("paginate", (True, False))
     def test_etag_set_etag_in_response(self, app, schemas, paginate):
@@ -390,7 +393,6 @@ class TestEtag:
         assert response.get_etag() == (blp._generate_etag("test"), False)
 
     def test_etag_operations_etag_enabled(self, app_with_etag):
-
         client = app_with_etag.test_client()
 
         # GET without ETag: OK
@@ -475,7 +477,6 @@ class TestEtag:
         assert response.status_code == 204
 
     def test_etag_operations_etag_disabled(self, app_with_etag):
-
         app_with_etag.config["ETAG_DISABLED"] = True
         client = app_with_etag.test_client()
 
@@ -540,3 +541,79 @@ class TestEtag:
             f"/test/{item_2_id}", headers={"If-Match": "dummy_etag"}
         )
         assert response.status_code == 204
+
+    @pytest.mark.parametrize("decorate", (True, False))
+    @pytest.mark.parametrize("has_response", (True, False))
+    @pytest.mark.parametrize("etag_disabled", (True, False))
+    @pytest.mark.parametrize(
+        "method", ("OPTIONS", "HEAD", "GET", "POST", "PUT", "PATCH", "DELETE")
+    )
+    def test_etag_documents_responses(
+        self,
+        app,
+        method,
+        decorate,
+        etag_disabled,
+        has_response,
+    ):
+        app.config["ETAG_DISABLED"] = etag_disabled
+        api = Api(app)
+        blp = Blueprint("test", "test", url_prefix="/test")
+
+        if decorate:
+            if has_response:
+
+                @blp.route("/", methods=[method])
+                @blp.response(204)
+                @blp.etag
+                def func():
+                    pass
+
+            else:
+
+                @blp.route("/", methods=[method])
+                @blp.etag
+                def func():
+                    pass
+
+        else:
+            if has_response:
+
+                @blp.route("/", methods=[method])
+                @blp.response(204)
+                def func():
+                    pass
+
+            else:
+
+                @blp.route("/", methods=[method])
+                def func():
+                    pass
+
+        api.register_blueprint(blp)
+
+        operation = api.spec.to_dict()["paths"]["/test/"][method.lower()]
+        responses = operation.get("responses", {})
+        response_headers = responses.get("204", {}).get("headers", {})
+        parameters = operation.get("parameters", [])
+
+        if not decorate or etag_disabled:
+            assert "304" not in responses
+            assert "412" not in responses
+            assert "428" not in responses
+            assert "IF_NONE_MATCH" not in parameters
+            assert "IF_MATCH" not in parameters
+            assert "ETag" not in response_headers
+        else:
+            assert ("304" in responses) == (method in ["GET", "HEAD"])
+            assert ("412" in responses) == (method in ["PUT", "PATCH", "DELETE"])
+            assert ("428" in responses) == (method in ["PUT", "PATCH", "DELETE"])
+            assert (
+                build_ref(api.spec, "parameter", "IF_NONE_MATCH") in parameters
+            ) == (method in ["GET", "HEAD"])
+            assert (build_ref(api.spec, "parameter", "IF_MATCH") in parameters) == (
+                method in ["PUT", "PATCH", "DELETE"]
+            )
+            assert not has_response or (
+                response_headers.get("ETag") == build_ref(api.spec, "header", "ETAG")
+            ) == (method in ["GET", "HEAD", "POST", "PUT", "PATCH"])
