@@ -153,7 +153,6 @@ def blueprint_fixture(request, collection, schemas):
 
 class TestFullExample:
     def test_examples(self, app, blueprint_fixture, schemas):
-
         blueprint, etag_schema = blueprint_fixture
 
         api = Api(app)
@@ -337,7 +336,6 @@ class TestCustomExamples:
         """Demonstrates how to wrap response payload in a data field"""
 
         class WrapperBlueprint(Blueprint):
-
             # Wrap payload data
             @staticmethod
             def _prepare_response_content(data):
@@ -393,7 +391,6 @@ class TestCustomExamples:
         """Demonstrates how to add pagination metadata in response payload"""
 
         class WrapperBlueprint(Blueprint):
-
             # Set pagination metadata in app context
             def _set_pagination_metadata(self, page_params, result, headers):
                 page_meta = self._make_pagination_metadata(
@@ -420,28 +417,29 @@ class TestCustomExamples:
                 if operation:
                     success_status_codes = doc_info.get("success_status_codes", [])
                     for success_status_code in success_status_codes:
-                        response = operation.get("responses", {}).get(
+                        responses = operation.get("responses", {}).get(
                             success_status_code
                         )
-                        if response is not None:
-                            if "schema" in response:
-                                schema = response["schema"]
-                                response["schema"] = type(
-                                    "Wrap" + schema.__class__.__name__,
-                                    (ma.Schema,),
-                                    {"data": ma.fields.Nested(schema)},
-                                )
-                                if "pagination" in doc_info:
+                        if responses is not None:
+                            for response in responses:
+                                if "schema" in response:
                                     schema = response["schema"]
                                     response["schema"] = type(
-                                        "Pagination" + schema.__name__,
-                                        (schema,),
-                                        {
-                                            "pagination": ma.fields.Nested(
-                                                PaginationMetadataSchema
-                                            )
-                                        },
+                                        "Wrap" + schema.__class__.__name__,
+                                        (ma.Schema,),
+                                        {"data": ma.fields.Nested(schema)},
                                     )
+                                    if "pagination" in doc_info:
+                                        schema = response["schema"]
+                                        response["schema"] = type(
+                                            "Pagination" + schema.__name__,
+                                            (schema,),
+                                            {
+                                                "pagination": ma.fields.Nested(
+                                                    PaginationMetadataSchema
+                                                )
+                                            },
+                                        )
                 return super(WrapperBlueprint, WrapperBlueprint)._prepare_response_doc(
                     doc, doc_info, spec=spec, **kwargs
                 )
